@@ -23,9 +23,10 @@ __revision__ = '$Id$'
 
 import logging
 import os
+from gettext import gettext as _
+
 import db
 import gutils
-from  main_treeview import treeview_selection_on_event
 
 log = logging.getLogger("Griffith")
 
