@@ -68,17 +68,18 @@ __license__ = "Python"
 # Modification to _contentsOf to strip trailing whitespace when loading Amazon key
 # from a file submitted by Patrick Phalen.
 
-# Support for specifying locale and associates ID as search parameters and 
+# Support for specifying locale and associates ID as search parameters and
 # internationalisation fix for the SalesRank integer conversion by
 # Christian Theune <ct@gocept.com>, gocept gmbh & co. kg
 
 # Support for BlendedSearch contributed by Alex Choo
 
 from xml.dom import minidom
-import os, sys, getopt, cgi, urllib.request, urllib.parse, urllib.error, string, time
+import os, sys, urllib.request, urllib.parse, urllib.error, string, time
 import base64
 import hmac
 from hashlib import sha256
+from gutils import cmp
 try:
     import timeoutsocket # http://www.timo-tasi.org/python/timeoutsocket.py
     timeoutsocket.setDefaultSocketTimeout(10)
@@ -112,7 +113,7 @@ _licenseLocations = (
     (lambda key: _contentsOf(_getScriptDir(), _amazonfile2), '%s in the amazon.py directory' % _amazonfile2)
     )
 _supportedLocales = {
-        "us" : (None, "ecs.amazonaws.com/onca/xml"),   
+        "us" : (None, "ecs.amazonaws.com/onca/xml"),
         "uk" : ("uk", "ecs.amazonaws.co.uk/onca/xml"),
         "de" : ("de", "ecs.amazonaws.de/onca/xml"),
         "ca" : ("ca", "ecs.amazonaws.ca/onca/xml"),
@@ -270,19 +271,19 @@ def buildURL(search_type, searchfield, searchvalue, product_line, type, page, li
 def getSignedUrl(base_url, params, timestamp = None):
     global HMAC
     hmac = HMAC.copy()
-    
+
     # Add a ISO 8601 compliant timestamp (in GMT)
     if timestamp:
         params['Timestamp'] = timestamp
     else:
         params['Timestamp'] = time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime())
     #params['SignatureVersion']='1'
-    
+
     # Sort the URL parameters by key
     keys = list(params.keys())
     #keys.sort(cmp = lambda x, y: cmp(x.lower(), y.lower()))
     keys.sort()
-    
+
     # Reconstruct the URL parameters and encode them
     pairs = []
     for key in keys:
@@ -292,7 +293,7 @@ def getSignedUrl(base_url, params, timestamp = None):
     url_string = '&'.join(pairs)
     url_string = url_string.replace('+', "%20")
     url_string = url_string.replace(':', "%3A")
-    
+
     #Construct the string to sign
     urlparts = base_url.split('/')
     string_to_sign = """GET
@@ -300,16 +301,16 @@ def getSignedUrl(base_url, params, timestamp = None):
 /%s/%s
 %s""" % (urlparts[2], urlparts[3], urlparts[4], url_string)
     url_string = url_string.replace(';', urllib.parse.quote(';'))
-    
+
     # Sign the request
     hmac.update(string_to_sign)
     signature = hmac.digest()
-    
+
     # Base64 encode the signature
     signature = base64.encodestring(signature).strip()
-    signature = signature.replace('+','%2B');
-    signature = signature.replace('=','%3D');
-    signature = signature.replace('/','%2F');
+    signature = signature.replace('+','%2B')
+    signature = signature.replace('=','%3D')
+    signature = signature.replace('/','%2F')
 
     # Make the signature URL safe
     url_string += "&Signature=%s" % signature
@@ -368,7 +369,7 @@ def search(search_type, searchfield, searchvalue, product_line, type = "Large",
     license_key = getLicense(license_key)
     locale = getLocale(locale)
     associate = getAssociate(associate)
-    url = buildURL(search_type, searchfield, searchvalue, product_line, type, page, 
+    url = buildURL(search_type, searchfield, searchvalue, product_line, type, page,
             license_key, locale, associate)
     proxies = getProxies(http_proxy)
     u = urllib.request.FancyURLopener(proxies)
@@ -381,16 +382,16 @@ def search(search_type, searchfield, searchvalue, product_line, type = "Large",
         if hasattr(data, 'BlendedSearch'):
             data = data.BlendedSearch
     elif hasattr(data, 'ItemSearchResponse'):
-        data = data.ItemSearchResponse 
+        data = data.ItemSearchResponse
     elif hasattr(data, 'ItemLookupResponse'):
-        data = data.ItemLookupResponse 
+        data = data.ItemLookupResponse
 
     if hasattr(data, 'Errors'):
         raise AmazonError(data.Errors)
     else:
         if search_type == "BlendedSearch":
-            return data 
-        else:            
+            return data
+        else:
             if hasattr(data, 'Items'):
                 return data.Items
             else:
