@@ -21,12 +21,13 @@ __revision__ = '$Id$'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-from plugins.imp import ImportPlugin as IP
-import gutils
-import string
+import logging
+from gettext import gettext as _
 from xml.dom import minidom, Node
 
-import logging
+import gutils
+from plugins.imp import ImportPlugin as IP
+
 log = logging.getLogger("Griffith")
 
 
